@@ -17,11 +17,11 @@ App::GitHooks::Hook - Base class for all git hook handlers.
 
 =head1 VERSION
 
-Version 1.2.1
+Version 1.3.0
 
 =cut
 
-our $VERSION = '1.2.1';
+our $VERSION = '1.3.0';
 
 
 =head1 METHODS
@@ -52,7 +52,7 @@ sub run
 	my $app = $args{'app'};
 
 	# Find all the plugins that are applicable for this hook.
-	my $plugins = $app->get_plugins( $app->get_hook_name() );
+	my $plugins = $app->get_hook_plugins( $app->get_hook_name() );
 
 	# Run all the plugins.
 	my $has_errors = 0;
