@@ -23,11 +23,11 @@ App::GitHooks::Hook::PreCommit - Handler for pre-commit hook.
 
 =head1 VERSION
 
-Version 1.2.1
+Version 1.3.0
 
 =cut
 
-our $VERSION = '1.2.1';
+our $VERSION = '1.3.0';
 
 
 =head1 METHODS
@@ -119,7 +119,7 @@ sub run_all_tests
 	my ( $app ) = @_;
 
 	# Find all the plugins that support the pre-commit hook.
-	my $plugins = $app->get_plugins( 'pre-commit' );
+	my $plugins = $app->get_hook_plugins( 'pre-commit' );
 
 	# Run the plugins.
 	my $tests_success = 1;
