@@ -23,11 +23,11 @@ App::GitHooks::Hook::CommitMsg - Handler for commit-msg hook.
 
 =head1 VERSION
 
-Version 1.2.1
+Version 1.3.0
 
 =cut
 
-our $VERSION = '1.2.1';
+our $VERSION = '1.3.0';
 
 
 =head1 METHODS
@@ -73,7 +73,7 @@ sub run
 
 	# Find and run all the plugins that support the prepare-commit-msg hook.
 	my $tests_success = 1;
-	my $plugins = $app->get_plugins( 'prepare-commit-msg' );
+	my $plugins = $app->get_hook_plugins( 'prepare-commit-msg' );
 	foreach my $plugin ( @$plugins )
 	{
 		my $check_result = $plugin->run_prepare_commit_msg(
